/*
--------------------------------------------------------------------------------
Title:              DC_motor_on_off_withLED
Description:        Three speeds to DC motor, determined by mouse click:
                    Left: low speed
                    Middle (scroll wheel): medium speed
                    Right: high speed

                    Four LEDs, controlled by mouse click and position:
                    Blue: on with left click in square
                    Red: on with right click in square
                      Both off with middle click in square
                    Green: on with left click outside of square
                    White: on with right click outside of square
                      Both off with middle click outside of square
                      
Author:             Taylor Yee
Created:            11/7/19
Last Modified:      11/7/19
Helpful Link(s):    https://processing.org/tutorials/electronics/
--------------------------------------------------------------------------------
*/

// Read data from the serial and turn a DC motor on or off according to the value

char val;             // Data received from the serial port
int motorpin = 9;     // Arduino: Connect L293D Pin En1 to Pin PWM 9
/*
 * Initializing LED pin numbers
 */
int blueLed = 2;
int redLed = 4;
int whiteLed = 7;
int greenLed = 8;

void setup() {
  Serial.begin(9600);                  // Start serial communication at 9600 bps
  /**
   * Initializing LEDs as digital output pins
   */
  pinMode(blueLed, OUTPUT);
  pinMode(redLed, OUTPUT);
  pinMode(whiteLed, OUTPUT);
  pinMode(greenLed, OUTPUT);
}

void loop() {
  if (Serial.available()) {            // If data is available,
    val = Serial.read();               // read it and store it in val
  }
  if (val == 'H') {                     // If 'H' was received,
    analogWrite(motorpin, 150);         // turn the motor on at high speed
    digitalWrite(redLed, HIGH);
  }
  else if (val == 'M') {                // If 'M' was received,
    analogWrite(motorpin, 100);         // turn the motor to medium speed
    digitalWrite(redLed, LOW);          // turn off blue and red LEDs
    digitalWrite(blueLed, LOW);
  }
  else if (val == 'L') {                // If 'L' was received
    analogWrite(motorpin, 75);          // turn the motor to lower speed
    digitalWrite(blueLed, HIGH);
  }
  else if (val == 'C'){                 // If 'C' was received
    digitalWrite(greenLed, HIGH);       // turn the green LED on
  }

  else if (val == 'E'){                 // If 'E' was received
    digitalWrite(whiteLed, HIGH);       // turn the white LED on
  }
  else if (val == 'D'){                 // If 'D' was received
    digitalWrite(greenLed, LOW);        // turn off green and white LEDs
    digitalWrite(whiteLed, LOW);
  }
  else{
    analogWrite(motorpin, 0);           // If any other serial values were received, turn the motor off
  }
  delay(100);                           // Wait 100 milliseconds for next reading
}