/*
--------------------------------------------------------------------------------
Title:              DC_motor_on_off_withLED
Description:        Three speeds to DC motor and four LEDs, determined by mouse
                    click and whether the mouse is over the designated area.

                    If OVER designated area:
                      Left: low speed, blue LED on
                      Middle (scroll wheel): medium speed, blue and red LEDs off
                      Right: high speed, red LED on
                    If NOT over designated area:
                      Left: green LED on
                      Middle (scroll wheel): green and white LEDs off
                      Right: white LED on
                    Manual "kill switch": side mouse buttons
                    
Author:             Taylor Yee
Created:            11/7/19
Last Modified:      11/7/19
Helpful Link(s):    https://processing.org/tutorials/electronics/
--------------------------------------------------------------------------------
*/

import processing.serial.*;

Serial port;                           // Create serial port object
boolean rectOver = false;
int rectX, rectY;                      // Position of square button
int rectSize = 100;                    // Diameter of rect
color rectColor;
boolean mousePressed = false;              // Status of the button
/**
 * Draws the rectangle, and initializes / opens the serial port for comms
 * between Arduino and computer / mouse clicks.
 */
void setup() {
  size(200, 200);
  noStroke();
  frameRate(10);
  rectColor = color(100);
  rectX = width/2 - rectSize/2;
  rectY = height/2 - rectSize/2;
  // Open the port that the board is connected to and use the same speed (9600 bps)
  port = new Serial(this, Serial.list()[0], 9600);
}

/**
 * draw() is the same as Arduino's loop() function, runs continuously.
 */
void draw() {
  update(mouseX, mouseY);
  background(0);                 // Clear background to black
  fill(rectColor);
  rect(rectX, rectY, rectSize, rectSize);
}

/**
 * Module that updates the boolean variable rectOver by calling the overRect()
 * function. This variable is used in the mouseReleased() function.
 */
void update(int x, int y) {
  if (overRect(rectX, rectY, rectSize, rectSize) == true) {
    rectOver = true;
  } else {
    rectOver = false;
  }
}

/**
 * mouseReleased() functions run once each time the mouse is released.
 * Arbitrary char values for port.write(), could be any char value.
 */
void mouseReleased() {
  /**
   * First set of statements for if the mouse is over the designated area.
   */
  if (rectOver == true) {
    if (mouseButton == LEFT){
      rectColor = color(50);
      port.write('L');
    }
    else if (mouseButton == CENTER){
      rectColor = color(100);
      port.write('M');
    }
    else if (mouseButton == RIGHT){
      rectColor = color(180);
      port.write('H');
    }
    else{
      rectColor = color(25);
      port.write('O');
    }
  /**
   * Second set of statements for if the mouse is NOT over the designated area.
   */
  }
  else if (rectOver == false){
    if (mouseButton == LEFT){
      port.write('C');
    }
    
    else if (mouseButton == RIGHT){
      port.write('E');
    }
    
    else{
      port.write('D');
    }
  }
}

/**
 * This module returns whether the mouse is over the rectangle specified in the
 * setup() function.
 */
boolean overRect(int x, int y, int width, int height) {
  if ((mouseX >= x) && (mouseX <= x+width) &&
      (mouseY >= y) && (mouseY <= y+height)) {
    return true;
  } else {
    return false;
  }
}
